from .index import EchorLogger, echorLogger

# You can specify which symbols should be exposed when users do "from package import *"
__all__ = ['EchorLogger', 'echorLogger']

# Optionally, you can add package metadata
__version__ = '0.1.0'